<?php

if (!function_exists('dax_entry_meta')) :
    function dax_entry_meta()
    {
        if (is_singular() || is_multi_author()) {
            printf('<span class="byline"><span class="author vcard"><span class="screen-reader-text">%1$s </span><a class="url fn n" href="%2$s">%3$s</a></span></span>',
                _x('Author', 'Used before post author name.', 'dax'),
                esc_url(get_author_posts_url(get_the_author_meta('ID'))),
                get_the_author()
            );
        }

        if (in_array(get_post_type(), array('post', 'attachment'))) {
            dax_entry_date();
        }

        $format = get_post_format();
        if (current_theme_supports('post-formats', $format)) {
            printf('<span class="entry-format">%1$s<a href="%2$s">%3$s</a></span>',
                sprintf('<span class="screen-reader-text">%s </span>', _x('Format', 'Used before post format.', 'dax')),
                esc_url(get_post_format_link($format)),
                get_post_format_string($format)
            );
        }

        if ('post' === get_post_type()) {
            dax_entry_taxonomies();
        }

        if (!is_singular() && !post_password_required() && (comments_open() || get_comments_number())) {
            echo '<span class="comments-link">';
            comments_popup_link(sprintf(__('Leave a comment<span class="screen-reader-text"> on %s</span>', 'dax'), get_the_title()));
            echo '</span>';
        }
    }
endif;

if (!function_exists('dax_entry_date')) :
    function dax_entry_date()
    {
        $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

        if (get_the_time('U') !== get_the_modified_time('U')) {
            $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
        }

        $time_string = sprintf($time_string,
            esc_attr(get_the_date('c')),
            get_the_date(),
            esc_attr(get_the_modified_date('c')),
            get_the_modified_date()
        );

        printf('<span class="posted-on"><span class="screen-reader-text">%1$s </span><a href="%2$s" rel="bookmark">%3$s</a></span>',
            _x('Posted on', 'Used before publish date.', 'dax'),
            esc_url(get_permalink()),
            $time_string
        );
    }
endif;

if (!function_exists('dax_entry_taxonomies')) :
    function dax_entry_taxonomies()
    {
        $categories_list = get_the_category_list(_x(', ', 'Used between list items, there is a space after the comma.', 'dax'));
        if ($categories_list && dax_categorized_blog()) {
            printf('<span class="cat-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
                _x('Categories', 'Used before category names.', 'dax'),
                $categories_list
            );
        }

        $tags_list = get_the_tag_list('', _x(', ', 'Used between list items, there is a space after the comma.', 'dax'));
        if ($tags_list) {
            printf('<span class="tags-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
                _x('Tags', 'Used before tag names.', 'dax'),
                $tags_list
            );
        }
    }
endif;

if (!function_exists('dax_post_thumbnail')) :
    function dax_post_thumbnail()
    {
        if (post_password_required() || is_attachment() || !has_post_thumbnail()) {
            return;
        }

        if (is_singular()) :
            ?>

            <div class="post-thumbnail">
                <?php the_post_thumbnail(); ?>
            </div>

        <?php else : ?>

            <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
                <?php the_post_thumbnail('post-thumbnail', array('alt' => the_title_attribute('echo=0'))); ?>
            </a>

        <?php endif;
    }
endif;

if (!function_exists('dax_excerpt')) :
    function dax_excerpt($class = 'entry-summary')
    {
        $class = esc_attr($class);

        if (has_excerpt() || is_search()) : ?>
            <div class="<?php echo $class; ?>">
                <?php the_excerpt(); ?>
            </div><!-- .<?php echo $class; ?> -->
        <?php endif;
    }
endif;

if (!function_exists('dax_excerpt_more') && !is_admin()) :
    function dax_excerpt_more()
    {
        $link = sprintf('<a href="%1$s" class="more-link">%2$s</a>',
            esc_url(get_permalink(get_the_ID())),
            sprintf(__('<span class="screen-reader-text"> "%s"</span>', 'dax'), get_the_title(get_the_ID()))
        );
        return ' &hellip; ' . $link;
    }

    add_filter('excerpt_more', 'dax_excerpt_more');
endif;

if (!function_exists('dax_categorized_blog')) :
    function dax_categorized_blog()
    {
        if (false === ($all_the_cool_cats = get_transient('dax_categories'))) {
            $all_the_cool_cats = get_categories(array(
                'fields' => 'ids',
                'number' => 2,
            ));

            $all_the_cool_cats = count($all_the_cool_cats);

            set_transient('dax_categories', $all_the_cool_cats);
        }

        if ($all_the_cool_cats > 1) {
            return true;
        } else {
            return false;
        }
    }
endif;

function dax_category_transient_flusher()
{
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
    // Like, beat it. Dig?
    delete_transient('dax_categories');
}

add_action('edit_category', 'dax_category_transient_flusher');
add_action('save_post', 'dax_category_transient_flusher');

if (!function_exists('dax_the_custom_logo')) :
    function dax_the_custom_logo()
    {
        if (function_exists('the_custom_logo')) {
            the_custom_logo();
        }
    }
endif;
